@@ -174,49 +174,28 @@ static PyGetSetDef DecompressionObj_getset[] = {
     {"eof", DecompressionObj_eof, NULL, NULL, NULL },
     {NULL}};
 
-PyTypeObject ZstdDecompressionObjType = {
-    PyVarObject_HEAD_INIT(NULL, 0) "zstd.ZstdDecompressionObj", /* tp_name */
-    sizeof(ZstdDecompressionObj),             /* tp_basicsize */
-    0,                                        /* tp_itemsize */
-    (destructor)DecompressionObj_dealloc,     /* tp_dealloc */
-    0,                                        /* tp_print */
-    0,                                        /* tp_getattr */
-    0,                                        /* tp_setattr */
-    0,                                        /* tp_compare */
-    0,                                        /* tp_repr */
-    0,                                        /* tp_as_number */
-    0,                                        /* tp_as_sequence */
-    0,                                        /* tp_as_mapping */
-    0,                                        /* tp_hash */
-    0,                                        /* tp_call */
-    0,                                        /* tp_str */
-    0,                                        /* tp_getattro */
-    0,                                        /* tp_setattro */
-    0,                                        /* tp_as_buffer */
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE, /* tp_flags */
-    0,                                        /* tp_doc */
-    0,                                        /* tp_traverse */
-    0,                                        /* tp_clear */
-    0,                                        /* tp_richcompare */
-    0,                                        /* tp_weaklistoffset */
-    0,                                        /* tp_iter */
-    0,                                        /* tp_iternext */
-    DecompressionObj_methods,                 /* tp_methods */
-    0,                                        /* tp_members */
-    DecompressionObj_getset,                  /* tp_getset */
-    0,                                        /* tp_base */
-    0,                                        /* tp_dict */
-    0,                                        /* tp_descr_get */
-    0,                                        /* tp_descr_set */
-    0,                                        /* tp_dictoffset */
-    0,                                        /* tp_init */
-    0,                                        /* tp_alloc */
-    PyType_GenericNew,                        /* tp_new */
+PyType_Slot ZstdDecompressionObjSlots[] = {
+    {Py_tp_dealloc, DecompressionObj_dealloc},
+    {Py_tp_methods, DecompressionObj_methods},
+    {Py_tp_getset, DecompressionObj_getset},
+    {Py_tp_new, PyType_GenericNew},
+    {0, NULL},
 };
 
+PyType_Spec ZstdDecompressionObjSpec = {
+    "zstd.ZstdDecompressionObj",
+    sizeof(ZstdDecompressionObj),
+    0,
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,
+    ZstdDecompressionObjSlots,
+};
+
+PyTypeObject *ZstdDecompressionObjType;
+
 void decompressobj_module_init(PyObject *module) {
-    Py_SET_TYPE(&ZstdDecompressionObjType, &PyType_Type);
-    if (PyType_Ready(&ZstdDecompressionObjType) < 0) {
+    ZstdDecompressionObjType =
+        (PyTypeObject *)PyType_FromSpec(&ZstdDecompressionObjSpec);
+    if (PyType_Ready(ZstdDecompressionObjType) < 0) {
         return;
     }
 }
